/* editable-entry.c generated by valac 0.34.0.71-0c51, the Vala compiler
 * generated from editable-entry.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/
/* Boxes.EditableEntry is based on gnome-control-center CcEditableEntry*/

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <pango/pango.h>
#include <float.h>
#include <math.h>
#include <cairo.h>
#include <gdk/gdk.h>


#define BOXES_TYPE_EDITABLE_ENTRY (boxes_editable_entry_get_type ())
#define BOXES_EDITABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EDITABLE_ENTRY, BoxesEditableEntry))
#define BOXES_EDITABLE_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EDITABLE_ENTRY, BoxesEditableEntryClass))
#define BOXES_IS_EDITABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EDITABLE_ENTRY))
#define BOXES_IS_EDITABLE_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EDITABLE_ENTRY))
#define BOXES_EDITABLE_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EDITABLE_ENTRY, BoxesEditableEntryClass))

typedef struct _BoxesEditableEntry BoxesEditableEntry;
typedef struct _BoxesEditableEntryClass BoxesEditableEntryClass;
typedef struct _BoxesEditableEntryPrivate BoxesEditableEntryPrivate;

#define BOXES_EDITABLE_ENTRY_TYPE_PAGE (boxes_editable_entry_page_get_type ())
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define __vala_PangoFontDescription_free0(var) ((var == NULL) ? NULL : (var = (_vala_PangoFontDescription_free (var), NULL)))
#define _pango_attr_list_unref0(var) ((var == NULL) ? NULL : (var = (pango_attr_list_unref (var), NULL)))
enum  {
	BOXES_EDITABLE_ENTRY_EDITING_DONE_SIGNAL,
	BOXES_EDITABLE_ENTRY_LAST_SIGNAL
};
static guint boxes_editable_entry_signals[BOXES_EDITABLE_ENTRY_LAST_SIGNAL] = {0};

struct _BoxesEditableEntry {
	GtkNotebook parent_instance;
	BoxesEditableEntryPrivate * priv;
	gboolean _editable;
};

struct _BoxesEditableEntryClass {
	GtkNotebookClass parent_class;
};

struct _BoxesEditableEntryPrivate {
	gchar* _text;
	PangoWeight _weight;
	gboolean _weight_set;
	gdouble _scale;
	gboolean _scale_set;
	GtkLabel* label;
	GtkLabel* button_label;
	GtkEntry* entry;
	gboolean in_stop_editing;
};

typedef enum  {
	BOXES_EDITABLE_ENTRY_PAGE_LABEL,
	BOXES_EDITABLE_ENTRY_PAGE_BUTTON,
	BOXES_EDITABLE_ENTRY_PAGE_ENTRY
} BoxesEditableEntryPage;


static gpointer boxes_editable_entry_parent_class = NULL;

#define EMPTY_TEXT "\xe2\x80\x94"
GType boxes_editable_entry_get_type (void) G_GNUC_CONST;
#define BOXES_EDITABLE_ENTRY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_EDITABLE_ENTRY, BoxesEditableEntryPrivate))
enum  {
	BOXES_EDITABLE_ENTRY_DUMMY_PROPERTY,
	BOXES_EDITABLE_ENTRY_TEXT,
	BOXES_EDITABLE_ENTRY_EDITABLE,
	BOXES_EDITABLE_ENTRY_SELECTABLE,
	BOXES_EDITABLE_ENTRY_TEXT_XALIGN,
	BOXES_EDITABLE_ENTRY_TEXT_YALIGN,
	BOXES_EDITABLE_ENTRY_WEIGHT_SET,
	BOXES_EDITABLE_ENTRY_SCALE,
	BOXES_EDITABLE_ENTRY_SCALE_SET
};
static GType boxes_editable_entry_page_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static void boxes_editable_entry_update_entry_font (BoxesEditableEntry* self, GtkEntry* entry);
gboolean boxes_editable_entry_get_scale_set (BoxesEditableEntry* self);
gboolean boxes_editable_entry_get_weight_set (BoxesEditableEntry* self);
static PangoFontDescription* _vala_PangoFontDescription_copy (PangoFontDescription* self);
gdouble boxes_editable_entry_get_scale (BoxesEditableEntry* self);
static void _vala_PangoFontDescription_free (PangoFontDescription* self);
static void boxes_editable_entry_update_fonts (BoxesEditableEntry* self);
void boxes_editable_entry_start_editing (BoxesEditableEntry* self);
static void boxes_editable_entry_stop_editing (BoxesEditableEntry* self);
void boxes_editable_entry_set_text (BoxesEditableEntry* self, const gchar* value);
static void boxes_editable_entry_cancel_editing (BoxesEditableEntry* self);
const gchar* boxes_editable_entry_get_text (BoxesEditableEntry* self);
BoxesEditableEntry* boxes_editable_entry_new (void);
BoxesEditableEntry* boxes_editable_entry_construct (GType object_type);
static void boxes_editable_entry_on_button_clicked (BoxesEditableEntry* self);
static void _boxes_editable_entry_on_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_editable_entry_on_button_label_size_allocate (BoxesEditableEntry* self, GtkWidget* widget, GtkAllocation* allocation);
static void _boxes_editable_entry_on_button_label_size_allocate_gtk_widget_size_allocate (GtkWidget* _sender, GtkAllocation* allocation, gpointer self);
static void boxes_editable_entry_on_entry_activated (BoxesEditableEntry* self);
static void _boxes_editable_entry_on_entry_activated_gtk_entry_activate (GtkEntry* _sender, gpointer self);
static gboolean boxes_editable_entry_on_entry_focused_out (BoxesEditableEntry* self);
static gboolean _boxes_editable_entry_on_entry_focused_out_gtk_widget_focus_out_event (GtkWidget* _sender, GdkEventFocus* event, gpointer self);
static gboolean boxes_editable_entry_on_entry_key_press_event (BoxesEditableEntry* self, GtkWidget* widget, GdkEventKey* event);
static gboolean _boxes_editable_entry_on_entry_key_press_event_gtk_widget_key_press_event (GtkWidget* _sender, GdkEventKey* event, gpointer self);
static void boxes_editable_entry_on_entry_style_updated (BoxesEditableEntry* self);
static void _boxes_editable_entry_on_entry_style_updated_gtk_widget_style_updated (GtkWidget* _sender, gpointer self);
gboolean boxes_editable_entry_get_editable (BoxesEditableEntry* self);
void boxes_editable_entry_set_editable (BoxesEditableEntry* self, gboolean value);
gboolean boxes_editable_entry_get_selectable (BoxesEditableEntry* self);
void boxes_editable_entry_set_selectable (BoxesEditableEntry* self, gboolean value);
gfloat boxes_editable_entry_get_text_xalign (BoxesEditableEntry* self);
void boxes_editable_entry_set_text_xalign (BoxesEditableEntry* self, gfloat value);
gfloat boxes_editable_entry_get_text_yalign (BoxesEditableEntry* self);
void boxes_editable_entry_set_text_yalign (BoxesEditableEntry* self, gfloat value);
void boxes_editable_entry_set_weight_set (BoxesEditableEntry* self, gboolean value);
void boxes_editable_entry_set_scale (BoxesEditableEntry* self, gdouble value);
void boxes_editable_entry_set_scale_set (BoxesEditableEntry* self, gboolean value);
static void boxes_editable_entry_finalize (GObject* obj);
static void _vala_boxes_editable_entry_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_editable_entry_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


static GType boxes_editable_entry_page_get_type (void) {
	static volatile gsize boxes_editable_entry_page_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_editable_entry_page_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_EDITABLE_ENTRY_PAGE_LABEL, "BOXES_EDITABLE_ENTRY_PAGE_LABEL", "label"}, {BOXES_EDITABLE_ENTRY_PAGE_BUTTON, "BOXES_EDITABLE_ENTRY_PAGE_BUTTON", "button"}, {BOXES_EDITABLE_ENTRY_PAGE_ENTRY, "BOXES_EDITABLE_ENTRY_PAGE_ENTRY", "entry"}, {0, NULL, NULL}};
		GType boxes_editable_entry_page_type_id;
		boxes_editable_entry_page_type_id = g_enum_register_static ("BoxesEditableEntryPage", values);
		g_once_init_leave (&boxes_editable_entry_page_type_id__volatile, boxes_editable_entry_page_type_id);
	}
	return boxes_editable_entry_page_type_id__volatile;
}


static PangoFontDescription* _vala_PangoFontDescription_copy (PangoFontDescription* self) {
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	return g_boxed_copy (pango_font_description_get_type (), self);
#line 145 "editable-entry.c"
}


static gpointer __vala_PangoFontDescription_copy0 (gpointer self) {
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	return self ? _vala_PangoFontDescription_copy (self) : NULL;
#line 152 "editable-entry.c"
}


static void _vala_PangoFontDescription_free (PangoFontDescription* self) {
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_boxed_free (pango_font_description_get_type (), self);
#line 159 "editable-entry.c"
}


static void boxes_editable_entry_update_entry_font (BoxesEditableEntry* self, GtkEntry* entry) {
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	GtkEntry* _tmp3_ = NULL;
	GtkEntry* _tmp4_ = NULL;
	PangoFontDescription* desc = NULL;
	GtkEntry* _tmp5_ = NULL;
	GtkStyleContext* _tmp6_ = NULL;
	GtkEntry* _tmp7_ = NULL;
	GtkStateFlags _tmp8_ = 0;
	PangoFontDescription* _tmp9_ = NULL;
	PangoFontDescription* _tmp10_ = NULL;
	gboolean _tmp11_ = FALSE;
	gboolean _tmp14_ = FALSE;
	GtkEntry* _tmp20_ = NULL;
	PangoFontDescription* _tmp21_ = NULL;
	GtkEntry* _tmp22_ = NULL;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_if_fail (self != NULL);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_if_fail (entry != NULL);
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp1_ = self->priv->_scale_set;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	if (!_tmp1_) {
#line 188 "editable-entry.c"
		gboolean _tmp2_ = FALSE;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp2_ = self->priv->_weight_set;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp0_ = !_tmp2_;
#line 194 "editable-entry.c"
	} else {
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp0_ = FALSE;
#line 198 "editable-entry.c"
	}
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	if (_tmp0_) {
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		return;
#line 204 "editable-entry.c"
	}
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp3_ = entry;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_signal_handlers_block_by_func (_tmp3_, (void*) boxes_editable_entry_update_entry_font, self);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp4_ = entry;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_widget_override_font ((GtkWidget*) _tmp4_, NULL);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp5_ = entry;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp6_ = gtk_widget_get_style_context ((GtkWidget*) _tmp5_);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp7_ = entry;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp8_ = gtk_widget_get_state_flags ((GtkWidget*) _tmp7_);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp9_ = gtk_style_context_get_font (_tmp6_, _tmp8_);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp10_ = __vala_PangoFontDescription_copy0 (_tmp9_);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	desc = _tmp10_;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp11_ = self->priv->_weight_set;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	if (_tmp11_) {
#line 232 "editable-entry.c"
		PangoFontDescription* _tmp12_ = NULL;
		PangoWeight _tmp13_ = 0;
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp12_ = desc;
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp13_ = self->priv->_weight;
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		pango_font_description_set_weight (_tmp12_, _tmp13_);
#line 241 "editable-entry.c"
	}
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp14_ = self->priv->_scale_set;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	if (_tmp14_) {
#line 247 "editable-entry.c"
		PangoFontDescription* _tmp15_ = NULL;
		gdouble _tmp16_ = 0.0;
		gdouble _tmp17_ = 0.0;
		PangoFontDescription* _tmp18_ = NULL;
		gint _tmp19_ = 0;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp15_ = desc;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp16_ = boxes_editable_entry_get_scale (self);
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp17_ = _tmp16_;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp18_ = desc;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp19_ = pango_font_description_get_size (_tmp18_);
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		pango_font_description_set_size (_tmp15_, (gint) (_tmp17_ * _tmp19_));
#line 265 "editable-entry.c"
	}
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp20_ = entry;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp21_ = desc;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_widget_override_font ((GtkWidget*) _tmp20_, _tmp21_);
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp22_ = entry;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_signal_handlers_unblock_by_func (_tmp22_, (void*) boxes_editable_entry_update_entry_font, self);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	__vala_PangoFontDescription_free0 (desc);
#line 279 "editable-entry.c"
}


static void boxes_editable_entry_update_fonts (BoxesEditableEntry* self) {
	PangoAttrList* attrs = NULL;
	PangoAttrList* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp6_ = FALSE;
	GtkLabel* _tmp10_ = NULL;
	PangoAttrList* _tmp11_ = NULL;
	GtkLabel* _tmp12_ = NULL;
	PangoAttrList* _tmp13_ = NULL;
	GtkEntry* _tmp14_ = NULL;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_if_fail (self != NULL);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp0_ = pango_attr_list_new ();
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	attrs = _tmp0_;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp1_ = self->priv->_scale_set;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	if (_tmp1_) {
#line 303 "editable-entry.c"
		PangoAttrList* _tmp2_ = NULL;
		gdouble _tmp3_ = 0.0;
		gdouble _tmp4_ = 0.0;
		PangoAttribute* _tmp5_ = NULL;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp2_ = attrs;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp3_ = boxes_editable_entry_get_scale (self);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp4_ = _tmp3_;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp5_ = pango_attr_scale_new (_tmp4_);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		pango_attr_list_insert (_tmp2_, _tmp5_);
#line 318 "editable-entry.c"
	}
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp6_ = self->priv->_weight_set;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	if (_tmp6_) {
#line 324 "editable-entry.c"
		PangoAttrList* _tmp7_ = NULL;
		PangoWeight _tmp8_ = 0;
		PangoAttribute* _tmp9_ = NULL;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp7_ = attrs;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp8_ = self->priv->_weight;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp9_ = pango_attr_weight_new (_tmp8_);
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		pango_attr_list_insert (_tmp7_, _tmp9_);
#line 336 "editable-entry.c"
	}
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp10_ = self->priv->label;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp11_ = attrs;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_label_set_attributes (_tmp10_, _tmp11_);
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp12_ = self->priv->button_label;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp13_ = attrs;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_label_set_attributes (_tmp12_, _tmp13_);
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp14_ = self->priv->entry;
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	boxes_editable_entry_update_entry_font (self, _tmp14_);
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_pango_attr_list_unref0 (attrs);
#line 356 "editable-entry.c"
}


void boxes_editable_entry_start_editing (BoxesEditableEntry* self) {
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_if_fail (self != NULL);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_object_set ((GtkNotebook*) self, "page", (gint) BOXES_EDITABLE_ENTRY_PAGE_ENTRY, NULL);
#line 365 "editable-entry.c"
}


static void boxes_editable_entry_stop_editing (BoxesEditableEntry* self) {
	gboolean _tmp0_ = FALSE;
	GtkEntry* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_if_fail (self != NULL);
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp0_ = self->priv->in_stop_editing;
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	if (_tmp0_) {
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		return;
#line 382 "editable-entry.c"
	}
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	self->priv->in_stop_editing = TRUE;
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_object_set ((GtkNotebook*) self, "page", (gint) BOXES_EDITABLE_ENTRY_PAGE_BUTTON, NULL);
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp1_ = self->priv->entry;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp2_ = gtk_entry_get_text (_tmp1_);
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp3_ = _tmp2_;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	boxes_editable_entry_set_text (self, _tmp3_);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_signal_emit (self, boxes_editable_entry_signals[BOXES_EDITABLE_ENTRY_EDITING_DONE_SIGNAL], 0);
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	self->priv->in_stop_editing = FALSE;
#line 400 "editable-entry.c"
}


static void boxes_editable_entry_cancel_editing (BoxesEditableEntry* self) {
	GtkEntry* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_if_fail (self != NULL);
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp0_ = self->priv->entry;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp1_ = boxes_editable_entry_get_text (self);
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp2_ = _tmp1_;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_entry_set_text (_tmp0_, _tmp2_);
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_object_set ((GtkNotebook*) self, "page", (gint) BOXES_EDITABLE_ENTRY_PAGE_BUTTON, NULL);
#line 420 "editable-entry.c"
}


BoxesEditableEntry* boxes_editable_entry_construct (GType object_type) {
	BoxesEditableEntry * self = NULL;
	GtkLabel* _tmp0_ = NULL;
	GtkLabel* _tmp1_ = NULL;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	self = (BoxesEditableEntry*) g_object_new (object_type, NULL);
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp0_ = self->priv->label;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_label_set_label (_tmp0_, EMPTY_TEXT);
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp1_ = self->priv->button_label;
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_label_set_label (_tmp1_, EMPTY_TEXT);
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	return self;
#line 440 "editable-entry.c"
}


BoxesEditableEntry* boxes_editable_entry_new (void) {
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	return boxes_editable_entry_construct (BOXES_TYPE_EDITABLE_ENTRY);
#line 447 "editable-entry.c"
}


static void boxes_editable_entry_on_button_clicked (BoxesEditableEntry* self) {
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_if_fail (self != NULL);
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	boxes_editable_entry_start_editing (self);
#line 456 "editable-entry.c"
}


static void _boxes_editable_entry_on_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	boxes_editable_entry_on_button_clicked ((BoxesEditableEntry*) self);
#line 463 "editable-entry.c"
}


static void boxes_editable_entry_on_button_label_size_allocate (BoxesEditableEntry* self, GtkWidget* widget, GtkAllocation* allocation) {
	GtkAllocation alloc = {0};
	GtkWidget* _tmp0_ = NULL;
	GtkContainer* _tmp1_ = NULL;
	GtkAllocation _tmp2_ = {0};
	gint offset = 0;
	GtkAllocation _tmp3_ = {0};
	gint _tmp4_ = 0;
	GtkAllocation _tmp5_ = {0};
	gint _tmp6_ = 0;
	gint _tmp7_ = 0;
	GtkLabel* _tmp8_ = NULL;
	gint _tmp9_ = 0;
	gint _tmp10_ = 0;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_if_fail (self != NULL);
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_if_fail (widget != NULL);
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_if_fail (allocation != NULL);
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp0_ = widget;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp1_ = (GtkContainer*) gtk_widget_get_parent (_tmp0_);
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_widget_get_allocation ((GtkWidget*) _tmp1_, &_tmp2_);
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	alloc = _tmp2_;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp3_ = *allocation;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp4_ = _tmp3_.x;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp5_ = alloc;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp6_ = _tmp5_.x;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	offset = _tmp4_ - _tmp6_;
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp7_ = offset;
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp8_ = self->priv->label;
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp9_ = gtk_widget_get_margin_start ((GtkWidget*) _tmp8_);
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp10_ = _tmp9_;
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	if (_tmp7_ != _tmp10_) {
#line 515 "editable-entry.c"
		GtkLabel* _tmp11_ = NULL;
		gint _tmp12_ = 0;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp11_ = self->priv->label;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp12_ = offset;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		gtk_misc_set_padding ((GtkMisc*) _tmp11_, _tmp12_, 0);
#line 524 "editable-entry.c"
	}
}


static void _boxes_editable_entry_on_button_label_size_allocate_gtk_widget_size_allocate (GtkWidget* _sender, GtkAllocation* allocation, gpointer self) {
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	boxes_editable_entry_on_button_label_size_allocate ((BoxesEditableEntry*) self, _sender, allocation);
#line 532 "editable-entry.c"
}


static void boxes_editable_entry_on_entry_activated (BoxesEditableEntry* self) {
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_if_fail (self != NULL);
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	boxes_editable_entry_stop_editing (self);
#line 541 "editable-entry.c"
}


static void _boxes_editable_entry_on_entry_activated_gtk_entry_activate (GtkEntry* _sender, gpointer self) {
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	boxes_editable_entry_on_entry_activated ((BoxesEditableEntry*) self);
#line 548 "editable-entry.c"
}


static gboolean boxes_editable_entry_on_entry_focused_out (BoxesEditableEntry* self) {
	gboolean result = FALSE;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	boxes_editable_entry_stop_editing (self);
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	result = FALSE;
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	return result;
#line 562 "editable-entry.c"
}


static gboolean _boxes_editable_entry_on_entry_focused_out_gtk_widget_focus_out_event (GtkWidget* _sender, GdkEventFocus* event, gpointer self) {
	gboolean result;
	result = boxes_editable_entry_on_entry_focused_out ((BoxesEditableEntry*) self);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	return result;
#line 571 "editable-entry.c"
}


static gboolean boxes_editable_entry_on_entry_key_press_event (BoxesEditableEntry* self, GtkWidget* widget, GdkEventKey* event) {
	gboolean result = FALSE;
	GdkEventKey* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_val_if_fail (widget != NULL, FALSE);
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp0_ = event;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp1_ = _tmp0_->keyval;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	if (_tmp1_ == ((guint) GDK_KEY_Escape)) {
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		boxes_editable_entry_cancel_editing (self);
#line 593 "editable-entry.c"
	}
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	result = FALSE;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	return result;
#line 599 "editable-entry.c"
}


static gboolean _boxes_editable_entry_on_entry_key_press_event_gtk_widget_key_press_event (GtkWidget* _sender, GdkEventKey* event, gpointer self) {
	gboolean result;
	result = boxes_editable_entry_on_entry_key_press_event ((BoxesEditableEntry*) self, _sender, event);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	return result;
#line 608 "editable-entry.c"
}


static void boxes_editable_entry_on_entry_style_updated (BoxesEditableEntry* self) {
	GtkEntry* _tmp0_ = NULL;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_if_fail (self != NULL);
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp0_ = self->priv->entry;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	boxes_editable_entry_update_entry_font (self, G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, gtk_entry_get_type ()) ? ((GtkEntry*) _tmp0_) : NULL);
#line 620 "editable-entry.c"
}


static void _boxes_editable_entry_on_entry_style_updated_gtk_widget_style_updated (GtkWidget* _sender, gpointer self) {
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	boxes_editable_entry_on_entry_style_updated ((BoxesEditableEntry*) self);
#line 627 "editable-entry.c"
}


const gchar* boxes_editable_entry_get_text (BoxesEditableEntry* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp0_ = self->priv->_text;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	result = _tmp0_;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	return result;
#line 642 "editable-entry.c"
}


void boxes_editable_entry_set_text (BoxesEditableEntry* self, const gchar* value) {
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_if_fail (self != NULL);
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	if (g_strcmp0 (value, boxes_editable_entry_get_text (self)) != 0) {
#line 651 "editable-entry.c"
		const gchar* _tmp0_ = NULL;
		gchar* _tmp1_ = NULL;
		GtkEntry* _tmp2_ = NULL;
		const gchar* _tmp3_ = NULL;
		gboolean _tmp4_ = FALSE;
		const gchar* _tmp5_ = NULL;
		GtkLabel* _tmp9_ = NULL;
		const gchar* _tmp10_ = NULL;
		GtkLabel* _tmp11_ = NULL;
		const gchar* _tmp12_ = NULL;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp0_ = value;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp1_ = g_strdup (_tmp0_);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_g_free0 (self->priv->_text);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		self->priv->_text = _tmp1_;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp2_ = self->priv->entry;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp3_ = value;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		gtk_entry_set_text (_tmp2_, _tmp3_);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp5_ = value;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		if (_tmp5_ == NULL) {
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
			_tmp4_ = TRUE;
#line 682 "editable-entry.c"
		} else {
			const gchar* _tmp6_ = NULL;
			gint _tmp7_ = 0;
			gint _tmp8_ = 0;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
			_tmp6_ = value;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
			_tmp7_ = strlen (_tmp6_);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
			_tmp8_ = _tmp7_;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
			_tmp4_ = _tmp8_ == 0;
#line 695 "editable-entry.c"
		}
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		if (_tmp4_) {
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
			value = EMPTY_TEXT;
#line 701 "editable-entry.c"
		}
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp9_ = self->priv->label;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp10_ = value;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		gtk_label_set_label (_tmp9_, _tmp10_);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp11_ = self->priv->button_label;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp12_ = value;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		gtk_label_set_label (_tmp11_, _tmp12_);
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		g_object_notify ((GObject *) self, "text");
#line 717 "editable-entry.c"
	}
}


gboolean boxes_editable_entry_get_editable (BoxesEditableEntry* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp0_ = self->_editable;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	result = _tmp0_;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	return result;
#line 733 "editable-entry.c"
}


void boxes_editable_entry_set_editable (BoxesEditableEntry* self, gboolean value) {
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_if_fail (self != NULL);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	if (boxes_editable_entry_get_editable (self) != value) {
#line 742 "editable-entry.c"
		gboolean _tmp0_ = FALSE;
		gboolean _tmp1_ = FALSE;
		gboolean _tmp2_ = FALSE;
		BoxesEditableEntryPage _tmp3_ = 0;
		gboolean _tmp4_ = FALSE;
		gboolean _tmp5_ = FALSE;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp0_ = value;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp1_ = self->_editable;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		if (_tmp0_ == _tmp1_) {
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
			return;
#line 757 "editable-entry.c"
		}
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp2_ = value;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		self->_editable = _tmp2_;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp4_ = boxes_editable_entry_get_editable (self);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp5_ = _tmp4_;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		if (_tmp5_) {
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
			_tmp3_ = BOXES_EDITABLE_ENTRY_PAGE_BUTTON;
#line 771 "editable-entry.c"
		} else {
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
			_tmp3_ = BOXES_EDITABLE_ENTRY_PAGE_LABEL;
#line 775 "editable-entry.c"
		}
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		g_object_set ((GtkNotebook*) self, "page", (gint) _tmp3_, NULL);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		g_object_notify ((GObject *) self, "editable");
#line 781 "editable-entry.c"
	}
}


gboolean boxes_editable_entry_get_selectable (BoxesEditableEntry* self) {
	gboolean result;
	GtkLabel* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp0_ = self->priv->label;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp1_ = gtk_label_get_selectable (_tmp0_);
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp2_ = _tmp1_;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	result = _tmp2_;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	return result;
#line 803 "editable-entry.c"
}


void boxes_editable_entry_set_selectable (BoxesEditableEntry* self, gboolean value) {
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_if_fail (self != NULL);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	if (boxes_editable_entry_get_selectable (self) != value) {
#line 812 "editable-entry.c"
		gboolean _tmp0_ = FALSE;
		GtkLabel* _tmp1_ = NULL;
		gboolean _tmp2_ = FALSE;
		gboolean _tmp3_ = FALSE;
		GtkLabel* _tmp4_ = NULL;
		gboolean _tmp5_ = FALSE;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp0_ = value;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp1_ = self->priv->label;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp2_ = gtk_label_get_selectable (_tmp1_);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp3_ = _tmp2_;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		if (_tmp0_ == _tmp3_) {
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
			return;
#line 831 "editable-entry.c"
		}
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp4_ = self->priv->label;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp5_ = value;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		gtk_label_set_selectable (_tmp4_, _tmp5_);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		g_object_notify ((GObject *) self, "selectable");
#line 841 "editable-entry.c"
	}
}


gfloat boxes_editable_entry_get_text_xalign (BoxesEditableEntry* self) {
	gfloat result;
	GtkLabel* _tmp0_ = NULL;
	gfloat _tmp1_ = 0.0F;
	gfloat _tmp2_ = 0.0F;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_val_if_fail (self != NULL, 0.0F);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp0_ = self->priv->label;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp1_ = gtk_label_get_xalign (_tmp0_);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp2_ = _tmp1_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	result = _tmp2_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	return result;
#line 863 "editable-entry.c"
}


void boxes_editable_entry_set_text_xalign (BoxesEditableEntry* self, gfloat value) {
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_if_fail (self != NULL);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	if (boxes_editable_entry_get_text_xalign (self) != value) {
#line 872 "editable-entry.c"
		GtkLabel* _tmp0_ = NULL;
		gfloat _tmp1_ = 0.0F;
		GtkLabel* _tmp2_ = NULL;
		gfloat _tmp3_ = 0.0F;
		GtkEntry* _tmp4_ = NULL;
		gfloat _tmp5_ = 0.0F;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp0_ = self->priv->label;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp1_ = value;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		gtk_label_set_xalign (_tmp0_, _tmp1_);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp2_ = self->priv->button_label;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp3_ = value;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		gtk_label_set_xalign (_tmp2_, _tmp3_);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp4_ = self->priv->entry;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp5_ = value;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		g_object_set (_tmp4_, "xalign", _tmp5_, NULL);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		g_object_notify ((GObject *) self, "text-xalign");
#line 899 "editable-entry.c"
	}
}


gfloat boxes_editable_entry_get_text_yalign (BoxesEditableEntry* self) {
	gfloat result;
	GtkLabel* _tmp0_ = NULL;
	gfloat _tmp1_ = 0.0F;
	gfloat _tmp2_ = 0.0F;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_val_if_fail (self != NULL, 0.0F);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp0_ = self->priv->label;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp1_ = gtk_label_get_yalign (_tmp0_);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp2_ = _tmp1_;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	result = _tmp2_;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	return result;
#line 921 "editable-entry.c"
}


void boxes_editable_entry_set_text_yalign (BoxesEditableEntry* self, gfloat value) {
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_if_fail (self != NULL);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	if (boxes_editable_entry_get_text_yalign (self) != value) {
#line 930 "editable-entry.c"
		GtkLabel* _tmp0_ = NULL;
		gfloat _tmp1_ = 0.0F;
		GtkLabel* _tmp2_ = NULL;
		gfloat _tmp3_ = 0.0F;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp0_ = self->priv->label;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp1_ = value;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		gtk_label_set_yalign (_tmp0_, _tmp1_);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp2_ = self->priv->button_label;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp3_ = value;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		gtk_label_set_yalign (_tmp2_, _tmp3_);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		g_object_notify ((GObject *) self, "text-yalign");
#line 949 "editable-entry.c"
	}
}


gboolean boxes_editable_entry_get_weight_set (BoxesEditableEntry* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp0_ = self->priv->_weight_set;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	result = _tmp0_;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	return result;
#line 965 "editable-entry.c"
}


void boxes_editable_entry_set_weight_set (BoxesEditableEntry* self, gboolean value) {
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_if_fail (self != NULL);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	if (boxes_editable_entry_get_weight_set (self) != value) {
#line 974 "editable-entry.c"
		gboolean _tmp0_ = FALSE;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp0_ = value;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		self->priv->_weight_set = _tmp0_;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		g_object_notify ((GObject *) self, "weight-set");
#line 982 "editable-entry.c"
	}
}


gdouble boxes_editable_entry_get_scale (BoxesEditableEntry* self) {
	gdouble result;
	gdouble _tmp0_ = 0.0;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_val_if_fail (self != NULL, 0.0);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp0_ = self->priv->_scale;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	result = _tmp0_;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	return result;
#line 998 "editable-entry.c"
}


void boxes_editable_entry_set_scale (BoxesEditableEntry* self, gdouble value) {
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_if_fail (self != NULL);
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	if (boxes_editable_entry_get_scale (self) != value) {
#line 1007 "editable-entry.c"
		gboolean _tmp0_ = FALSE;
		gdouble _tmp1_ = 0.0;
		gdouble _tmp2_ = 0.0;
		gdouble _tmp4_ = 0.0;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp1_ = value;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp2_ = self->priv->_scale;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		if (_tmp1_ == _tmp2_) {
#line 1018 "editable-entry.c"
			gboolean _tmp3_ = FALSE;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
			_tmp3_ = self->priv->_scale_set;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
			_tmp0_ = _tmp3_;
#line 1024 "editable-entry.c"
		} else {
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
			_tmp0_ = FALSE;
#line 1028 "editable-entry.c"
		}
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		if (_tmp0_) {
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
			return;
#line 1034 "editable-entry.c"
		}
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp4_ = value;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		self->priv->_scale = _tmp4_;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		boxes_editable_entry_set_scale_set (self, TRUE);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		boxes_editable_entry_update_fonts (self);
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		g_object_notify ((GObject *) self, "scale");
#line 1046 "editable-entry.c"
	}
}


gboolean boxes_editable_entry_get_scale_set (BoxesEditableEntry* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp0_ = self->priv->_scale_set;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	result = _tmp0_;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	return result;
#line 1062 "editable-entry.c"
}


void boxes_editable_entry_set_scale_set (BoxesEditableEntry* self, gboolean value) {
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_if_fail (self != NULL);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	if (boxes_editable_entry_get_scale_set (self) != value) {
#line 1071 "editable-entry.c"
		gboolean _tmp0_ = FALSE;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp0_ = value;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		self->priv->_scale_set = _tmp0_;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		g_object_notify ((GObject *) self, "scale-set");
#line 1079 "editable-entry.c"
	}
}


static void boxes_editable_entry_class_init (BoxesEditableEntryClass * klass) {
	gint BoxesEditableEntry_private_offset;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	boxes_editable_entry_parent_class = g_type_class_peek_parent (klass);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_type_class_add_private (klass, sizeof (BoxesEditableEntryPrivate));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_editable_entry_get_property;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_editable_entry_set_property;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_editable_entry_finalize;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_EDITABLE_ENTRY_TEXT, g_param_spec_string ("text", "text", "text", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_EDITABLE_ENTRY_EDITABLE, g_param_spec_boolean ("editable", "editable", "editable", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_EDITABLE_ENTRY_SELECTABLE, g_param_spec_boolean ("selectable", "selectable", "selectable", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_EDITABLE_ENTRY_TEXT_XALIGN, g_param_spec_float ("text-xalign", "text-xalign", "text-xalign", -G_MAXFLOAT, G_MAXFLOAT, 0.0F, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_EDITABLE_ENTRY_TEXT_YALIGN, g_param_spec_float ("text-yalign", "text-yalign", "text-yalign", -G_MAXFLOAT, G_MAXFLOAT, 0.0F, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_EDITABLE_ENTRY_WEIGHT_SET, g_param_spec_boolean ("weight-set", "weight-set", "weight-set", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_EDITABLE_ENTRY_SCALE, g_param_spec_double ("scale", "scale", "scale", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_EDITABLE_ENTRY_SCALE_SET, g_param_spec_boolean ("scale-set", "scale-set", "scale-set", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	BoxesEditableEntry_private_offset = g_type_class_get_instance_private_offset (klass);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/editable-entry.ui");
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	boxes_editable_entry_signals[BOXES_EDITABLE_ENTRY_EDITING_DONE_SIGNAL] = g_signal_new ("editing_done", BOXES_TYPE_EDITABLE_ENTRY, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "label", FALSE, BoxesEditableEntry_private_offset + G_STRUCT_OFFSET (BoxesEditableEntryPrivate, label));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "button_label", FALSE, BoxesEditableEntry_private_offset + G_STRUCT_OFFSET (BoxesEditableEntryPrivate, button_label));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "entry", FALSE, BoxesEditableEntry_private_offset + G_STRUCT_OFFSET (BoxesEditableEntryPrivate, entry));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_button_clicked", G_CALLBACK(_boxes_editable_entry_on_button_clicked_gtk_button_clicked));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_button_label_size_allocate", G_CALLBACK(_boxes_editable_entry_on_button_label_size_allocate_gtk_widget_size_allocate));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_entry_activated", G_CALLBACK(_boxes_editable_entry_on_entry_activated_gtk_entry_activate));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_entry_focused_out", G_CALLBACK(_boxes_editable_entry_on_entry_focused_out_gtk_widget_focus_out_event));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_entry_key_press_event", G_CALLBACK(_boxes_editable_entry_on_entry_key_press_event_gtk_widget_key_press_event));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_entry_style_updated", G_CALLBACK(_boxes_editable_entry_on_entry_style_updated_gtk_widget_style_updated));
#line 1136 "editable-entry.c"
}


static void boxes_editable_entry_instance_init (BoxesEditableEntry * self) {
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	self->priv = BOXES_EDITABLE_ENTRY_GET_PRIVATE (self);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	self->priv->_weight = PANGO_WEIGHT_NORMAL;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	self->priv->_scale = 1.0;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 1149 "editable-entry.c"
}


static void boxes_editable_entry_finalize (GObject* obj) {
	BoxesEditableEntry * self;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_EDITABLE_ENTRY, BoxesEditableEntry);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_g_free0 (self->priv->_text);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_g_object_unref0 (self->priv->label);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_g_object_unref0 (self->priv->button_label);
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_g_object_unref0 (self->priv->entry);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	G_OBJECT_CLASS (boxes_editable_entry_parent_class)->finalize (obj);
#line 1167 "editable-entry.c"
}


GType boxes_editable_entry_get_type (void) {
	static volatile gsize boxes_editable_entry_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_editable_entry_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesEditableEntryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_editable_entry_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesEditableEntry), 0, (GInstanceInitFunc) boxes_editable_entry_instance_init, NULL };
		GType boxes_editable_entry_type_id;
		boxes_editable_entry_type_id = g_type_register_static (gtk_notebook_get_type (), "BoxesEditableEntry", &g_define_type_info, 0);
		g_once_init_leave (&boxes_editable_entry_type_id__volatile, boxes_editable_entry_type_id);
	}
	return boxes_editable_entry_type_id__volatile;
}


static void _vala_boxes_editable_entry_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesEditableEntry * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_EDITABLE_ENTRY, BoxesEditableEntry);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	switch (property_id) {
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		case BOXES_EDITABLE_ENTRY_TEXT:
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		g_value_set_string (value, boxes_editable_entry_get_text (self));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		break;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		case BOXES_EDITABLE_ENTRY_EDITABLE:
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		g_value_set_boolean (value, boxes_editable_entry_get_editable (self));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		break;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		case BOXES_EDITABLE_ENTRY_SELECTABLE:
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		g_value_set_boolean (value, boxes_editable_entry_get_selectable (self));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		break;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		case BOXES_EDITABLE_ENTRY_TEXT_XALIGN:
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		g_value_set_float (value, boxes_editable_entry_get_text_xalign (self));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		break;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		case BOXES_EDITABLE_ENTRY_TEXT_YALIGN:
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		g_value_set_float (value, boxes_editable_entry_get_text_yalign (self));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		break;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		case BOXES_EDITABLE_ENTRY_WEIGHT_SET:
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		g_value_set_boolean (value, boxes_editable_entry_get_weight_set (self));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		break;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		case BOXES_EDITABLE_ENTRY_SCALE:
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		g_value_set_double (value, boxes_editable_entry_get_scale (self));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		break;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		case BOXES_EDITABLE_ENTRY_SCALE_SET:
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		g_value_set_boolean (value, boxes_editable_entry_get_scale_set (self));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		break;
#line 1236 "editable-entry.c"
		default:
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		break;
#line 1242 "editable-entry.c"
	}
}


static void _vala_boxes_editable_entry_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesEditableEntry * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_EDITABLE_ENTRY, BoxesEditableEntry);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	switch (property_id) {
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		case BOXES_EDITABLE_ENTRY_TEXT:
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		boxes_editable_entry_set_text (self, g_value_get_string (value));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		break;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		case BOXES_EDITABLE_ENTRY_EDITABLE:
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		boxes_editable_entry_set_editable (self, g_value_get_boolean (value));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		break;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		case BOXES_EDITABLE_ENTRY_SELECTABLE:
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		boxes_editable_entry_set_selectable (self, g_value_get_boolean (value));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		break;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		case BOXES_EDITABLE_ENTRY_TEXT_XALIGN:
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		boxes_editable_entry_set_text_xalign (self, g_value_get_float (value));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		break;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		case BOXES_EDITABLE_ENTRY_TEXT_YALIGN:
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		boxes_editable_entry_set_text_yalign (self, g_value_get_float (value));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		break;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		case BOXES_EDITABLE_ENTRY_WEIGHT_SET:
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		boxes_editable_entry_set_weight_set (self, g_value_get_boolean (value));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		break;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		case BOXES_EDITABLE_ENTRY_SCALE:
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		boxes_editable_entry_set_scale (self, g_value_get_double (value));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		break;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		case BOXES_EDITABLE_ENTRY_SCALE_SET:
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		boxes_editable_entry_set_scale_set (self, g_value_get_boolean (value));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		break;
#line 1300 "editable-entry.c"
		default:
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		break;
#line 1306 "editable-entry.c"
	}
}



